.. _whatsnew_0130:

v0.1.3 (August 2, 2016)
-----------------------

This is a minor release, changes include:

* Bug fix for dataframes using timezones. There was an issue retaining the 
  timezone across the entire pecos analysis chain. The timezone was not stored 
  properly in the testing results. This is a known pandas bug. 
  The fix in Pecos includes stronger tests for analysis that use timezones.
* The use of Jinja for html report templates
* Cleaned up examples

